<#
  Original script taken from: https://github.com/MattiasC85/Scripts/blob/master/OSD/Download-AppxFromStore.ps1
#>

Param (
  [Parameter(Mandatory=$True)] [string] $StoreURL
)

if ($StoreURL.EndsWith("/")) {
  $StoreURL=$StoreURL.Remove($StoreUrl.Length-1,1)
}

$wchttp = [System.Net.WebClient]::new()
$URI = "https://store.rg-adguard.net/api/GetFiles"
$myParameters = "type=url&url=$($StoreURL)"
$wchttp.Headers[[System.Net.HttpRequestHeader]::ContentType]="application/x-www-form-urlencoded"
$HtmlResult = $wchttp.UploadString($URI,$myParameters)

$start=$HtmlResult.IndexOf("<p>The links were successfully received from the Microsoft Store server.</p>")
write-host $start

if ($Start -eq -1) {
  write-host "Could not get the links, please check the StoreURL."
  exit
}

$TableEnd=($HtmlResult.LastIndexOf("</table>")+8)
$SemiCleaned=$HtmlResult.Substring($start,$TableEnd-$start)

$newHtml=New-Object -ComObject "HTMLFile"
try {
  # This works in PowerShell with Office installed
  $newHtml.IHTMLDocument2_write($SemiCleaned)
} catch {
  # This works when Office is not installed    
  $src = [System.Text.Encoding]::Unicode.GetBytes($SemiCleaned)
  $newHtml.write($src)
}

$ToDownload=$newHtml.getElementsByTagName("a") | Select-Object textContent, href

$LastFrontSlash=$StoreURL.LastIndexOf("/")
$ProductID=($StoreURL -split "/").split()[-2]

if (!(test-path "$ProductID")) {
    write-host "Creating directory $ProductID"
    try {
        New-Item -ItemType Directory "$ProductID" -ErrorAction Stop | Out-Null
    } catch {
        write-host "Failed to create directory.$([System.environment]::NewLine)$_"
        write-host "Exiting..."
        exit
    }
}

Foreach ($Download in $ToDownload) {
  Write-host "Downloading $($Download.textContent)..."
  $wchttp.DownloadFile($Download.href, "$ProductID\$($Download.textContent)")
}

write-host "---------------------------------------"
write-host "Download is complete. Your files are in directory [ $ProductID ] ..." 

